%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script for creating input files and solving polynomial systems based on
% lamination parameter or ABD term targets. This is essentially a driver
% for the TargConstruction.m and parsePHC.m functions.
%
% - Creates 'square' systems with as many unknown ply angles as targets.
% - Assumes that the PHC executable is in the path
% - Uses the PHC 'blackbox' solver, which appends the full list of
% solutions back to the input file. Might be slow for large systems for
% which it is better to create start systems once and run the coefficient
% continuation step separately.
%
% Updated: 20191003, ADV
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%% GENERAL INPUTS %%%%%%%%%%%%%%%%%%
% The file name for the PHCpack input file:
PHCInputFile = 'LPEg01_Input.txt';
% The file name for the PHCpack output file:
PHCOutputFile = 'LPEg01_Output.txt';

% The type of laminate:
LamType = 'reg'; %'reg','sym','asym'

%%%%%%%%%%%%%%% LP INPUTS %%%%%%%%%%%%%%%%%%%%%%%
% LAMINATION PARAMETER TARGETS
% The full vector of lamination parameters:
M = nan(1,12);

% Specify the targets, leaving all other entries as NaN:
M(5) = -0.15; % V1B
M(6) = 0.4; % V2B
M(7) = 0.2; % V3B
M(8) = -0.7; % V4B

% Construct the input file:
[S,TargStruc] = TargConstruction(M,LamType,PHCInputFile,[]);


%%%%%%%%%%%%%%% CALL PHC %%%%%%%%%%%%%%%%%%%%%%%%
% Check if there is already an output file with this name:
if isfile(PHCOutputFile)
     delete(PHCOutputFile)
end

% Run PHC on the input file:
PHCCommand = ['phc -t -b ',PHCInputFile,' ',PHCOutputFile];
% PHCCommand = ['/usr/local/bin/phc -t -b ',PHCInputFile,' ',PHCOutputFile];
[st,re] = system(PHCCommand);

% Parse the result:
[M,solNumVec,varNames,realResults,conjStruc,realAngles] = parsePHC(PHCInputFile);
fprintf('The layups found (in degrees) are: \n')
format short
disp(realAngles)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





